<?php

/**
 * Allow themable wrapping of all comments.
 */
function phptemplate_comment_wrapper($content, $type = null) {
  static $node_type;
  if (isset($type)) $node_type = $type;

  if (!$content || $node_type == 'forum') {
    return '<div id="comments">'. $content . '</div>';
  }
  else {
    return '<div id="comments"><h2 class="comments">'. t('Comments') .'</h2>'. $content .'</div>';
  }
}

/**
 * Override or insert PHPTemplate variables into the templates.
 */
function _phptemplate_variables($hook, $vars) {
  if ($hook == 'page') {
    $arBodyClass = array();

    // if it's not front page and show current page in breadcrumbs are turned on, add current page to breadcrumbs
    if (!drupal_is_front_page()) {
      if (theme_get_setting('artistsC01_showCurrentInBreadcrumbs')) {
        $breadcrumbs = drupal_get_breadcrumb();
        // add current page
        $breadcrumbs[] = drupal_get_title();
        $vars['breadcrumb'] = theme('breadcrumb',  $breadcrumbs);
      }
    }

    // change the site_footer and footer blocks order
    $vars['footer_message'] = theme('blocks', 'footer') . "\n" . "<p>" . filter_xss_admin(variable_get('site_footer', FALSE)) . "</p>";

    $style = theme_get_setting('artistsC01_style');
    if ($style) { $arBodyClass[] = $style; }
    else { $arBodyClass[] = 'default'; }

    if (theme_get_setting('artistsC01_useSuckerfish'))
    {
      $vars['suckerfishPrimary'] = artistsC01_suckerfish_menu_tree();
    }

    // get color scheme
    $colorScheme = theme_get_setting('artistsC01_colorScheme');
    if (!isset($colorScheme)) { $colorScheme = 'blueLagoon'; }

    $arBodyClass[] = "colorScheme-" . $colorScheme;

    $customHeaderColor = theme_get_setting('artistsC01_customHeaderColor');
    if ($customHeaderColor)
    {
      $vars['customHeaderColor'] = $customHeaderColor;
    }

    $vars['logo'] = artistsC01_get_logo($colorScheme);

    $useCustomColumnWidths = theme_get_setting('artistsC01_useCustomColumnWidths');
    if ($useCustomColumnWidths) {
      $mainContentWidth = intval(theme_get_setting('artistsC01_mainContentWidth'));
      $sidebarWidth = intval(theme_get_setting('artistsC01_sidebarWidth'));
      if ($mainContentWidth < 75) { $mainContentWidth = 736; }
      if ($sidebarWidth < 25) { $sidebarWidth = 210; }

      $vars['artefUseCustomColumnWidths'] = true;

      $vars['artefWidth_span_full'] = $mainContentWidth + $sidebarWidth + 10;
      $vars['artefWidth_span_segments_full'] = $vars['artefWidth_span_full'] + 20;
      $vars['artefWidth_span_main_content'] = $mainContentWidth;
      $vars['artefWidth_span_main_content_padded'] = $mainContentWidth - 8;
      $vars['artefWidth_span_main_content_half'] = floor(($mainContentWidth-10)/2);
      $vars['artefWidth_span_main_content_half_padded'] = $vars['artefWidth_span_main_content_half'] - 8;
      $vars['artefWidth_span_main_content_third'] = floor(($mainContentWidth-10)/3);
      $vars['artefWidth_span_main_content_two_thirds'] = $mainContentWidth - $vars['artefWidth_span_main_content_third'] - 10;
      $vars['artefWidth_span_sidebar_normal'] = $sidebarWidth;
      $vars['artefWidth_span_sidebar_normal_padded'] = $sidebarWidth - 4;
    }

    $vars['bodyClass'] = implode($arBodyClass, ' ');

    return $vars;
  }
  return array();
}

function artistsC01_suckerfish_menu_item($mid, $class='', $children = NULL, $isExpanded = TRUE) {
  $class .= $children ? ($isExpanded ? ' submenu expanded' : ' submenu collapsed') : ' leaf';
  $class .= menu_in_active_trail($mid) ? ' active' : '';
  $class = trim($class);

  $output = '<li class="'. $class .'">';
  $link = menu_item_link($mid, false);
  $link['attributes']['class'] = trim($link['attributes']['class'] . ' ' . $class);
  $innerHtml = l($link['title'], $link['href'], $link['attributes']);

  if ($children) {

    $innerSuckerfishHtml = artistsC01_suckerfish_menu_tree($mid);
    if ($innerSuckerfishHtml) {
      // replace </a> with whats needed hack
      $innerHtml = substr($innerHtml, 0, -4);
      $innerHtml .=  '<!--[if IE 7]><!--></a><!--<![endif]--><!--[if lte IE 6]><table><tr><td><![endif]--><div class="suckerfish-secondary-wrapper">' . $innerSuckerfishHtml . '</div><!--[if lte IE 6]></td></tr></table></a><![endif]-->';
    }
  }

  $output .= $innerHtml . '</li>';

  return $output;
}

function artistsC01_suckerfish_menu_tree($parentMenuId = 0)
{
  if (!module_exists('menu')) {
    return NULL;
  }
  if (!$parentMenuId) {
    $parentMenuId = variable_get('menu_primary_menu', 0);
  }
  if (!$parentMenuId) {
    return NULL;
  }

  // get the menu
  $menu = menu_get_menu();

  $parentLevel = 1;
  $parentMenu = $menu['visible'][$parentMenuId];
  while ($parentMenu['pid'])
  {
    $parentMenu = $menu['visible'][$parentMenu['pid']];
    $parentLevel += 1;
  }

  // Suckerfishes with more than 2 levels are no currently supported (missing css)
  if ($parentLevel>2) {
    return '';
  }

  $output = '';

  if (is_array($menu['visible'][$parentMenuId]) && isset($menu['visible'][$parentMenuId]['children'])) {
    // What happens with a leaf (no children) here?

    $output .= '<ul class="suckerfish-primary suckerfish-primary-' . $parentLevel . '">';

    // it has submenus
    $count = 1;
    $isFirst = true;
    foreach ($menu['visible'][$parentMenuId]['children'] as $cid) {

      $class = "menu-$parentLevel-$count-$parentMenuId";
      if (menu_in_active_trail_in_submenu($cid, $parentMenuId)) {
        $class .= "-active active";
      }
      if ($isFirst) {
        $isFirst = false;
        $class .= " sf-first";
      }
      if ($count == count($menu['visible'][$parentMenuId]['children']))
      {
        $class .= " sf-last";
      }

      $type = isset($menu['visible'][$cid]['type']) ? $menu['visible'][$cid]['type'] : NULL;
      $children = isset($menu['visible'][$cid]['children']) ? $menu['visible'][$cid]['children'] : NULL;

      $output .= artistsC01_suckerfish_menu_item($cid, $class, $children);

      $count++;
    }

    $output .= '</ul>';
  }


  return $output;
}

/**
 * Generates breadcrumbs if turned on.
 *
 * @param array $breadcrumb
 * @return string
 */
function artistsC01_breadcrumb($breadcrumb) {

  if (!theme_get_setting('artistsC01_showBreadcrumbs')) {
    return;
  }

  if (!empty($breadcrumb)) {
    $output = '<div class="breadcrumb">';
    $isFirst = true;
    foreach ($breadcrumb as $curr) {
      if ($isFirst) {
        $output .= '<span class="breadcrumb-first">' . $curr . '</span>';
        $isFirst = false;
      }
      else {
        $output .= ' › ' . $curr;
      }
    }
    return $output . '</div>';
  }
}

/**
 * Overriden to insert theme help on theme configuration page.
 *
 * @return string
 */
function artistsC01_help() {
   return theme_help() . t(artistsC01_get_theme_help());
}

/**
 * Function returns html help for artistsC01 theme.
 *
 * @return string
 * help for artistsC01 configuration page
 */
function artistsC01_get_theme_help() {
  $output = '';

  if (arg(0)=='admin' && arg(1)=='build' && arg(2)=='block' && !arg(3))
  {
    $output .= '<h3><strong>artistsC01 block configuration</strong></h3>';
    $output .= '<p>Highlights regions and categories collapse and expand in special way. As other regions in this theme, if you leave region empty it will collapse. Collapsed right region does not modify layout. When left region colapses, right region in the same row will <strong>expand</strong> to take full <strong>width</strong>. </p>';
    $output .= '<p>Having in mind how highlights and categories collapse, one can configure four different layouts.</p>';
  }

  return $output;
}

/**
 * Return code that emits an XML icon.
 * Added theme code for theme population tracking.
 */
function artistsC01_xml_icon($url) {
  if ($image = theme('image', 'misc/xml.png', t('XML feed') . ' (C01 _th3me_)', t('XML feed'))) {
    return '<a href="'. check_url($url) .'" class="xml-icon">'. $image. '</a>';
  }
}

/**
 * Return code that emits an feed icon.
 * Added theme code for theme population tracking.
 */
function artistsC01_feed_icon($url) {
  if ($image = theme('image', 'misc/feed.png', t('Syndicate content') . ' (C01 _th3me_)', t('Syndicate content'))) {
    return '<a href="'. check_url($url) .'" class="feed-icon">'. $image. '</a>';
  }
}


/**
* Declare the available regions implemented by this engine.
*
* @return
* An array of regions. Each array element takes the format:
* variable_name => t('human readable name')
*/
function artistsC01_regions() {
  return array(
    'header' => t('Header'),
    'banner_upper' => t('Banner Upper'),
    'highlight_left' => t('Highlight Left'),
    'highlight_right' => t('Highlight Right'),
    'banner_middle_1' => t('Banner Middle 1'),
    'banner_middle_2' => t('Banner Middle 2'),
    'content' => t('Content'),
    'category_1' => t('Category I Left'),
    'category_2' => t('Category I Right'),
    'category_3' => t('Category II Left'),
    'category_4' => t('Category II Right'),
    'category_5' => t('Category III Left'),
    'category_6' => t('Category III Right'),
    'category_7' => t('Category IV Left'),
    'category_8' => t('Category IV Right'),
    'banner_lower' => t('Banner Lower'),
    'right' => t('Right Sidebar'),
    'right_sidebar_box_1' => t('Right Sidebar Box 1'),
    'right_sidebar_box_2' => t('Right Sidebar Box 2'),
    'right_sidebar_box_3' => t('Right Sidebar Box 3'),
    'right_sidebar_box_4' => t('Right Sidebar Box 4'),
    'right_sidebar_box_5' => t('Right Sidebar Box 5'),
    'right_sidebar_box_6' => t('Right Sidebar Box 6'),
    'footer' => t('Footer')
    );
}

// Following section adds css files based on theme settings

$style = theme_get_setting('artistsC01_style');

if ($style && $style != 'default') {
  drupal_add_css(drupal_get_path('theme', 'artistsC01') . '/css/custom_style_' . $style . '.css', 'theme');
}

$colorScheme = theme_get_setting('artistsC01_colorScheme');

if (!isset($colorScheme)) {
  $colorScheme = 'blueLagoon';
}

if ($colorScheme != 'plain') {
  drupal_add_css(drupal_get_path('theme', 'artistsC01') . '/css/custom_colorScheme_' . $colorScheme . '.css', 'theme');
}

drupal_add_css(drupal_get_path('theme', 'artistsC01') . '/css/custom_fonts.css', 'theme');
//TODO
//drupal_add_css(drupal_get_path('theme', 'artistsC01') . '/print.css', 'theme', 'print');

